<?php

namespace CountriesStates\CountriesState\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use CountriesStates\CountriesState\Http\Requests\CitiesRequest;
use CountriesStates\CountriesState\Models\Cities;

/**
 * Admin web controller class.
 */
class CitiesWorkflowController extends BaseController
{

    /**
     * Workflow controller function for cities.
     *
     * @param Model   $cities
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CitiesRequest $request, Cities $cities, $step)
    {

        try {

            $cities->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('countries_state::cities.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/cities/cities/' . $cities->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/cities/cities/' . $cities->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for cities.
     *
     * @param Model   $cities
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Cities $cities, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $cities->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('countries_state::cities.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('countries_state::admin.cities.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('countries_state::admin.cities.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('countries_state::admin.cities.message', $data)->render();

        }

    }
}
