<?php

namespace CountriesStates\CountriesState\Policies;

use Litepie\User\Contracts\UserPolicy;
use CountriesStates\CountriesState\Models\Area;

class AreaPolicy
{

    /**
     * Determine if the given user can view the area.
     *
     * @param UserPolicy $user
     * @param Area $area
     *
     * @return bool
     */
    public function view(UserPolicy $user, Area $area)
    {
        if ($user->canDo('countries_state.area.view') && $user->isAdmin()) {
            return true;
        }

        return $area->user_id == user_id() && $area->user_type == user_type();
    }

    /**
     * Determine if the given user can create a area.
     *
     * @param UserPolicy $user
     * @param Area $area
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('countries_state.area.create');
    }

    /**
     * Determine if the given user can update the given area.
     *
     * @param UserPolicy $user
     * @param Area $area
     *
     * @return bool
     */
    public function update(UserPolicy $user, Area $area)
    {
        if ($user->canDo('countries_state.area.edit') && $user->isAdmin()) {
            return true;
        }

        return $area->user_id == user_id() && $area->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given area.
     *
     * @param UserPolicy $user
     * @param Area $area
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Area $area)
    {
        return $area->user_id == user_id() && $area->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given area.
     *
     * @param UserPolicy $user
     * @param Area $area
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Area $area)
    {
        if ($user->canDo('countries_state.area.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given area.
     *
     * @param UserPolicy $user
     * @param Area $area
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Area $area)
    {
        if ($user->canDo('countries_state.area.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
