<?php

namespace CountriesStates\CountriesState\Policies;

use Litepie\User\Contracts\UserPolicy;
use CountriesStates\CountriesState\Models\Cities;

class CitiesPolicy
{

    /**
     * Determine if the given user can view the cities.
     *
     * @param UserPolicy $user
     * @param Cities $cities
     *
     * @return bool
     */
    public function view(UserPolicy $user, Cities $cities)
    {
        if ($user->canDo('countries_state.cities.view') && $user->isAdmin()) {
            return true;
        }

        return $cities->user_id == user_id() && $cities->user_type == user_type();
    }

    /**
     * Determine if the given user can create a cities.
     *
     * @param UserPolicy $user
     * @param Cities $cities
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('countries_state.cities.create');
    }

    /**
     * Determine if the given user can update the given cities.
     *
     * @param UserPolicy $user
     * @param Cities $cities
     *
     * @return bool
     */
    public function update(UserPolicy $user, Cities $cities)
    {
        if ($user->canDo('countries_state.cities.edit') && $user->isAdmin()) {
            return true;
        }

        return $cities->user_id == user_id() && $cities->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given cities.
     *
     * @param UserPolicy $user
     * @param Cities $cities
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Cities $cities)
    {
        return $cities->user_id == user_id() && $cities->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given cities.
     *
     * @param UserPolicy $user
     * @param Cities $cities
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Cities $cities)
    {
        if ($user->canDo('countries_state.cities.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cities.
     *
     * @param UserPolicy $user
     * @param Cities $cities
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Cities $cities)
    {
        if ($user->canDo('countries_state.cities.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
