<?php

namespace CountriesStates\CountriesState\Policies;

use Litepie\User\Contracts\UserPolicy;
use CountriesStates\CountriesState\Models\Countries;

class CountriesPolicy
{

    /**
     * Determine if the given user can view the countries.
     *
     * @param UserPolicy $user
     * @param Countries $countries
     *
     * @return bool
     */
    public function view(UserPolicy $user, Countries $countries)
    {
        if ($user->canDo('countries_state.countries.view') && $user->isAdmin()) {
            return true;
        }

        return $countries->user_id == user_id() && $countries->user_type == user_type();
    }

    /**
     * Determine if the given user can create a countries.
     *
     * @param UserPolicy $user
     * @param Countries $countries
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('countries_state.countries.create');
    }

    /**
     * Determine if the given user can update the given countries.
     *
     * @param UserPolicy $user
     * @param Countries $countries
     *
     * @return bool
     */
    public function update(UserPolicy $user, Countries $countries)
    {
        if ($user->canDo('countries_state.countries.edit') && $user->isAdmin()) {
            return true;
        }

        return $countries->user_id == user_id() && $countries->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given countries.
     *
     * @param UserPolicy $user
     * @param Countries $countries
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Countries $countries)
    {
        return $countries->user_id == user_id() && $countries->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given countries.
     *
     * @param UserPolicy $user
     * @param Countries $countries
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Countries $countries)
    {
        if ($user->canDo('countries_state.countries.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given countries.
     *
     * @param UserPolicy $user
     * @param Countries $countries
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Countries $countries)
    {
        if ($user->canDo('countries_state.countries.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
