<?php

namespace CountriesStates\CountriesState\Policies;

use Litepie\User\Contracts\UserPolicy;
use CountriesStates\CountriesState\Models\States;

class StatesPolicy
{

    /**
     * Determine if the given user can view the states.
     *
     * @param UserPolicy $user
     * @param States $states
     *
     * @return bool
     */
    public function view(UserPolicy $user, States $states)
    {
        if ($user->canDo('countries_state.states.view') && $user->isAdmin()) {
            return true;
        }

        return $states->user_id == user_id() && $states->user_type == user_type();
    }

    /**
     * Determine if the given user can create a states.
     *
     * @param UserPolicy $user
     * @param States $states
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('countries_state.states.create');
    }

    /**
     * Determine if the given user can update the given states.
     *
     * @param UserPolicy $user
     * @param States $states
     *
     * @return bool
     */
    public function update(UserPolicy $user, States $states)
    {
        if ($user->canDo('countries_state.states.edit') && $user->isAdmin()) {
            return true;
        }

        return $states->user_id == user_id() && $states->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given states.
     *
     * @param UserPolicy $user
     * @param States $states
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, States $states)
    {
        return $states->user_id == user_id() && $states->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given states.
     *
     * @param UserPolicy $user
     * @param States $states
     *
     * @return bool
     */
    public function verify(UserPolicy $user, States $states)
    {
        if ($user->canDo('countries_state.states.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given states.
     *
     * @param UserPolicy $user
     * @param States $states
     *
     * @return bool
     */
    public function approve(UserPolicy $user, States $states)
    {
        if ($user->canDo('countries_state.states.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
