<?php

namespace CountriesStates\CountriesState\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use CountriesStates\CountriesState\Models\CountriesState;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'CountriesStates\CountriesState\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/countries_state/countries/*')) {
            Route::bind('countries', function ($countries) {
                $countriesrepo = $this->app->make('CountriesStates\CountriesState\Interfaces\CountriesRepositoryInterface');
                return $countriesrepo->findorNew($countries);
            });
        }
        if (Request::is('*/countries_state/states/*')) {
            Route::bind('states', function ($states) {
                $statesrepo = $this->app->make('CountriesStates\CountriesState\Interfaces\StatesRepositoryInterface');
                return $statesrepo->findorNew($states);
            });
        }
        if (Request::is('*/countries_state/cities/*')) {
            Route::bind('cities', function ($cities) {
                $citiesrepo = $this->app->make('CountriesStates\CountriesState\Interfaces\CitiesRepositoryInterface');
                return $citiesrepo->findorNew($cities);
            });
        }
        if (Request::is('*/countries_state/area/*')) {
            Route::bind('area', function ($area) {
                $arearepo = $this->app->make('CountriesStates\CountriesState\Interfaces\AreaRepositoryInterface');
                return $arearepo->findorNew($area);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
