<?php

namespace CountriesStates\CountriesState\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind Countries workflow validator
        'CountriesStates\CountriesState\Models\Countries' => \CountriesStates\CountriesState\Workflow\CountriesValidator::class,
        // Bind States workflow validator
        'CountriesStates\CountriesState\Models\States' => \CountriesStates\CountriesState\Workflow\StatesValidator::class,
        // Bind Cities workflow validator
        'CountriesStates\CountriesState\Models\Cities' => \CountriesStates\CountriesState\Workflow\CitiesValidator::class,
        // Bind Area workflow validator
        'CountriesStates\CountriesState\Models\Area' => \CountriesStates\CountriesState\Workflow\AreaValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind Countries workflow actions
        'CountriesStates\CountriesState\Models\Countries' => \CountriesStates\CountriesState\Workflow\CountriesAction::class,
        // Bind States workflow actions
        'CountriesStates\CountriesState\Models\States' => \CountriesStates\CountriesState\Workflow\StatesAction::class,
        // Bind Cities workflow actions
        'CountriesStates\CountriesState\Models\Cities' => \CountriesStates\CountriesState\Workflow\CitiesAction::class,
        // Bind Area workflow actions
        'CountriesStates\CountriesState\Models\Area' => \CountriesStates\CountriesState\Workflow\AreaAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind Countries workflow notifiers
        'CountriesStates\CountriesState\Models\Countries' => \CountriesStates\CountriesState\Workflow\CountriesNotifier::class,
        // Bind States workflow notifiers
        'CountriesStates\CountriesState\Models\States' => \CountriesStates\CountriesState\Workflow\StatesNotifier::class,
        // Bind Cities workflow notifiers
        'CountriesStates\CountriesState\Models\Cities' => \CountriesStates\CountriesState\Workflow\CitiesNotifier::class,
        // Bind Area workflow notifiers
        'CountriesStates\CountriesState\Models\Area' => \CountriesStates\CountriesState\Workflow\AreaNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
