<?php

namespace CountriesStates\CountriesState\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use CountriesStates\CountriesState\Models\Area;

class AreaAction
{
    /**
     * Perform the complete action.
     *
     * @param Area $area
     *
     * @return Area
     */
    public function complete(Area $area)
    {
        try {
            $area->status = 'complete';
            return $area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Area $area
     *
     * @return Area
     */public function verify(Area $area)
    {
        try {
            $area->status = 'verify';
            return $area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Area $area
     *
     * @return Area
     */public function approve(Area $area)
    {
        try {
            $area->status = 'approve';
            return $area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Area $area
     *
     * @return Area
     */public function publish(Area $area)
    {
        try {
            $area->status = 'publish';
            return $area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Area $area
     *
     * @return Area
     */
    public function archive(Area $area)
    {
        try {
            $area->status = 'archive';
            return $area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Area $area
     *
     * @return Area
     */
    public function unpublish(Area $area)
    {
        try {
            $area->status = 'unpublish';
            return $area->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
