<?php

namespace CountriesStates\CountriesState\Workflow;

use CountriesStates\CountriesState\Models\Area;
use Validator;

class AreaValidator
{

    /**
     * Determine if the given area is valid for complete status.
     *
     * @param Area $area
     *
     * @return bool / Validator
     */
    public function complete(Area $area)
    {
        return Validator::make($area->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given area is valid for verify status.
     *
     * @param Area $area
     *
     * @return bool / Validator
     */
    public function verify(Area $area)
    {
        return Validator::make($area->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given area is valid for approve status.
     *
     * @param Area $area
     *
     * @return bool / Validator
     */
    public function approve(Area $area)
    {
        return Validator::make($area->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given area is valid for publish status.
     *
     * @param Area $area
     *
     * @return bool / Validator
     */
    public function publish(Area $area)
    {
        return Validator::make($area->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given area is valid for archive status.
     *
     * @param Area $area
     *
     * @return bool / Validator
     */
    public function archive(Area $area)
    {
        return Validator::make($area->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given area is valid for unpublish status.
     *
     * @param Area $area
     *
     * @return bool / Validator
     */
    public function unpublish(Area $area)
    {
        return Validator::make($area->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
