<?php

namespace CountriesStates\CountriesState\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use CountriesStates\CountriesState\Models\Cities;

class CitiesAction
{
    /**
     * Perform the complete action.
     *
     * @param Cities $cities
     *
     * @return Cities
     */
    public function complete(Cities $cities)
    {
        try {
            $cities->status = 'complete';
            return $cities->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Cities $cities
     *
     * @return Cities
     */public function verify(Cities $cities)
    {
        try {
            $cities->status = 'verify';
            return $cities->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Cities $cities
     *
     * @return Cities
     */public function approve(Cities $cities)
    {
        try {
            $cities->status = 'approve';
            return $cities->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Cities $cities
     *
     * @return Cities
     */public function publish(Cities $cities)
    {
        try {
            $cities->status = 'publish';
            return $cities->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Cities $cities
     *
     * @return Cities
     */
    public function archive(Cities $cities)
    {
        try {
            $cities->status = 'archive';
            return $cities->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Cities $cities
     *
     * @return Cities
     */
    public function unpublish(Cities $cities)
    {
        try {
            $cities->status = 'unpublish';
            return $cities->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
