<?php

namespace CountriesStates\CountriesState\Workflow;

use CountriesStates\CountriesState\Models\Countries;
use Validator;

class CountriesValidator
{

    /**
     * Determine if the given countries is valid for complete status.
     *
     * @param Countries $countries
     *
     * @return bool / Validator
     */
    public function complete(Countries $countries)
    {
        return Validator::make($countries->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given countries is valid for verify status.
     *
     * @param Countries $countries
     *
     * @return bool / Validator
     */
    public function verify(Countries $countries)
    {
        return Validator::make($countries->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given countries is valid for approve status.
     *
     * @param Countries $countries
     *
     * @return bool / Validator
     */
    public function approve(Countries $countries)
    {
        return Validator::make($countries->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given countries is valid for publish status.
     *
     * @param Countries $countries
     *
     * @return bool / Validator
     */
    public function publish(Countries $countries)
    {
        return Validator::make($countries->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given countries is valid for archive status.
     *
     * @param Countries $countries
     *
     * @return bool / Validator
     */
    public function archive(Countries $countries)
    {
        return Validator::make($countries->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given countries is valid for unpublish status.
     *
     * @param Countries $countries
     *
     * @return bool / Validator
     */
    public function unpublish(Countries $countries)
    {
        return Validator::make($countries->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
